import React, { useState, useEffect } from 'react'
import _ from 'lodash'
import { getFields, getTasks } from './services/AsanaService'
import IncidentsChart from './components/IncidentsChart'
import ProductsChart from './components/ProductsChart'
import ServicesChart from './components/ServicesChart'
import ServiceInfo from './components/ServiceInfo'


const App = () => {
  const [fields, setFields] = useState([])
  const [tasks, setTasks] = useState([])
  const [loading, setLoading] = useState(true)
  const [statusMsg, setStatusMsg] = useState('Loading...')

  useEffect(async () => {
    // get information from api
    setStatusMsg('Getting fields information...')
    await getFields(setFields)

    setStatusMsg('Fetching records...')
    await getTasks(setTasks)

    // set loading to false
    setLoading(false)
  }, [])

  return <div className="container mx-auto pt-4 px-4 min-h-screen overflow-x-hidden">
      {
      loading === true ? statusMsg : <>
        <div className="flex flex-col">
          <div className="my-2">
            <h1 className="font-bold text-2xl text-center">Incidents Graph</h1>
          </div>
          <div>
            <IncidentsChart atasks={tasks} />
          </div>
        </div>
        <div className="mt-4 flex flex-col">
          <div className="my-2">
            <h1 className="font-bold text-2xl text-center">Impacted Products Graph</h1>
          </div>
          <div>
            <ProductsChart fields={fields} tasks={tasks} />
          </div>
        </div>
        <div className="mt-4 flex flex-col">
          <div className="my-2">
            <h1 className="font-bold text-2xl text-center">Service Impact Graphs</h1>
          </div>
          <div className="flex flex-wrap md:flex-nowrap">
            <ServicesChart fields={fields[0]} idx={0} tasks={tasks} />
            <ServicesChart fields={fields[1]} idx={1} tasks={tasks} />
          </div>
        </div>

        <div className="mt-4 flex flex-col my-4">
          <div className="mb-2">
            <p className="text-xl">Service Impact Information</p>
          </div>
          <div className="flex flex-col">
            <ServiceInfo fields={fields} tasks={tasks} />
          </div>
        </div>
      </>
      }
    </div>
}

export default App
